==> text-highlighter-1.0.0.tgz: package/lib/text-highlighter.js <==

/*!
 * text-highlighter.js v1.0.0
 * https://github.com/isoden/text-highlighter.git
 *
 * Copyright (c) 2015 isoden <isoda@maboroshi.biz> (http://isoden.me)
 * Licensed under the MIT license.
 */
    (function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define([], factory);
	else if(typeof exports === 'object')
		exports["TextHighlighter"] = factory();
	else
		root["TextHighlighter"] = factory();
})(this, function() {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};

/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {

/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId])
/******/ 			return installedModules[moduleId].exports;

/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			exports: {},
/******/ 			id: moduleId,
/******/ 			loaded: false
/******/ 		};

/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);

/******/ 		// Flag the module as loaded
/******/ 		module.loaded = true;

/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}


/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;

/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;

/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";

/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(0);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ function(module, exports) {

	/**
	 * 配列の最初の要素を返却する
	 * @param  array 対象の配列
	 * @return 最初の要素
	 */
	function first(array) {
	    return array == null ? void 0 : array[0];
	}
	module.exports = (function () {
	    function TextHighlighter(el) {
	        this.el = el;
	    }
	    /**
	     * ホワイトスペース文字をパイプ記号で置き換える
	     * @param  str 入力文字列
	     * @return 置き換え後の文字列
	     */
	    TextHighlighter._replaceWhitespaceWithPipe = function (str) {
	        if (str === void 0) { str = ''; }
	        return str.trim().replace(/\s+/g, '|');
	    };
	    /**
	     * 正規表現で特殊な意味を持つ記号をエスケープする
	     * @param  str 入力文字列
	     * @return エスケープ後の文字列
	     */
	    TextHighlighter._escapeRegExp = function (str) {
	        if (str === void 0) { str = ''; }
	        return str.replace(/([.*+?^=!:${}()|[\]\/\\])/g, '\\$1');
	    };
	    /**
	     * _getFullWidthAndHalfWidth
	     */
	    TextHighlighter._getFullWidthAndHalfWidth = function (str) {
	        if (str === void 0) { str = ''; }
	        return str.split('').map(function (v) {
	            // 全角⇔半角に変換可能な場合は全角半角両方にマッチするようにする (例: a => (?:a|ａ))
	            return /[！-～!-~]/.test(v)
	                ? "(?:" + TextHighlighter._escapeRegExp(TextHighlighter._toHalfWidth(v)) + "|" + TextHighlighter._escapeRegExp(TextHighlighter._toFullWidth(v)) + ")"
	                : TextHighlighter._escapeRegExp(v);
	        }).join('');
	    };
	    /**
	     * 全角文字を半角文字に変換する
	     * @param  str 入力文字列
	     * @return 半角に変換後の文字列
	     */
	    TextHighlighter._toHalfWidth = function (str) {
	        if (str === void 0) { str = ''; }
	        return str.replace(/[！-～]/g, function (match) { return String.fromCharCode(match.charCodeAt(0) - 0xFEE0); });
	    };
	    /**
	     * 半角文字を全角文字に変換する
	     * @param  str 入力文字列
	     * @return 全角に変換後の文字列
	     */
	    TextHighlighter._toFullWidth = function (str) {
	        if (str === void 0) { str = ''; }
	        return str.replace(/[!-~]/g, function (match) { return String.fromCharCode(match.charCodeAt(0) + 0xFEE0); });
	    };
	    /**
	     * ハイライト要素を作成する
	     * @param  attrs ハイライト要素の属性
	     * @return ハイライト要素
	     */
	    TextHighlighter._createMarker = function (attrs) {
	        var node = document.createElement('mark');
	        Object.keys(attrs).forEach(function (key) { return node[key] = attrs[key]; });
	        return node;
	    };
	    /**
	     * el要素内のテキストから検索ワードと一致するテキストを探す
	     * @param searchWord 検索ワード
	     */
	    TextHighlighter.prototype.highlight = function (searchWord) {
	        if (searchWord === void 0) { searchWord = ''; }
	        this.rxSearchWords = this._getRxSearchWords(searchWord);
	        this.dehighlight();
	        if (!searchWord)
	            return;
	        this._findRecursive(this.el);
	    };
	    /**
	     * ハイライト表示をやめる
	     */
	    TextHighlighter.prototype.dehighlight = function () {
	        Array.prototype.forEach.call(this.el.querySelectorAll('mark'), function (node) {
	            node.parentNode.replaceChild(node.firstChild, node);
	        });
	        this.el.normalize();
	    };
	    /**
	     * 検索用の正規表現オブジェクトを返却する
	     * @param  searchWord 検索テキスト
	     * @param  正規表現のフラグ
	     * @return パースした正規表現オブジェクト
	     */
	    TextHighlighter.prototype._getRxSearchWords = function (searchWord, flag) {
	        if (searchWord === void 0) { searchWord = ''; }
	        if (flag === void 0) { flag = 'gi'; }
	        return new RegExp(TextHighlighter._replaceWhitespaceWithPipe(TextHighlighter._getFullWidthAndHalfWidth(searchWord)), flag);
	    };
	    /**
	     * 要素内から検索ワードを再帰的に検索する
	     * @param node
	     */
	    TextHighlighter.prototype._findRecursive = function (node) {
	        if (node.nodeType === Node.TEXT_NODE) {
	            var text = node.data;
	            var matchedIndex = text.search(this.rxSearchWords);
	            var words = text.slice(matchedIndex).match(this.rxSearchWords);
	            var word = first(words);
	            var wordLength = (word || '').length;
	            if (matchedIndex > -1) {
	                var rest = document.createTextNode(text.substr(matchedIndex + wordLength));
	                var markNode = TextHighlighter._createMarker({ className: 'highlight' });
	                node.data = text.substr(0, matchedIndex);
	                markNode.appendChild(document.createTextNode(text.substr(matchedIndex, wordLength)));
	                node.parentNode.insertBefore(rest, node.nextSibling);
	                node.parentNode.insertBefore(markNode, node.nextSibling);
	                this._findRecursive(rest);
	            }
	        }
	        else if (node.nodeType === Node.ELEMENT_NODE) {
	            Array.prototype.forEach.call(node.childNodes, this._findRecursive.bind(this));
	        }
	    };
	    return TextHighlighter;
	})();


/***/ }
/******/ ])
});
;

==> text-highlighter-1.0.2.tgz: package/lib/text-highlighter.js <==

/*!
 * text-highlighter.js v1.0.2
 * https://github.com/isoden/text-highlighter.git
 *
 * Copyright (c) 2015 isoden <isoda@maboroshi.biz> (http://isoden.me)
 * Licensed under the MIT license.
 */
    (function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define([], factory);
	else if(typeof exports === 'object')
		exports["TextHighlighter"] = factory();
	else
		root["TextHighlighter"] = factory();
})(this, function() {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};

/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {

/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId])
/******/ 			return installedModules[moduleId].exports;

/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			exports: {},
/******/ 			id: moduleId,
/******/ 			loaded: false
/******/ 		};

/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);

/******/ 		// Flag the module as loaded
/******/ 		module.loaded = true;

/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}


/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;

/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;

/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";

/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(0);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ function(module, exports, __webpack_require__) {

	var util_1 = __webpack_require__(1);
	var nativeForEach = Array.prototype.forEach;
	module.exports = (function () {
	    function TextHighlighter(el) {
	        this.el = el;
	    }
	    /**
	     * ホワイトスペース文字をパイプ記号で置き換える
	     * @param  str 入力文字列
	     * @return 置き換え後の文字列
	     */
	    TextHighlighter._replaceWhitespaceWithPipe = function (str) {
	        if (str === void 0) { str = ''; }
	        return str.trim().replace(/\s+/g, '|');
	    };
	    /**
	     * 全角・半角にマッチするように変換したテキストを返却する
	     * @param  str 入力文字列
	     * @return 変換後の文字列
	     */
	    TextHighlighter._getFullWidthAndHalfWidth = function (str) {
	        if (str === void 0) { str = ''; }
	        return str.split('').map(function (v) {
	            // 全角⇔半角に変換可能な場合は全角半角両方にマッチするようにする (例: a => (?:a|ａ))
	            return /[！-～!-~]/.test(v)
	                ? "(?:" + util_1.escapeRegExp(util_1.toHalfWidth(v)) + "|" + util_1.escapeRegExp(util_1.toFullWidth(v)) + ")"
	                : util_1.escapeRegExp(v);
	        }).join('');
	    };
	    /**
	     * ハイライト要素を作成する
	     * @param  attrs ハイライト要素の属性
	     * @return ハイライト要素
	     */
	    TextHighlighter._createMarker = function (attrs) {
	        var node = document.createElement('mark');
	        Object.keys(attrs).forEach(function (key) { return node[key] = attrs[key]; });
	        return node;
	    };
	    /**
	     * el要素内のテキストから検索ワードと一致するテキストを探す
	     * @param searchWord 検索ワード
	     */
	    TextHighlighter.prototype.highlight = function (searchWord) {
	        if (searchWord === void 0) { searchWord = ''; }
	        this.rxSearchWords = this._getRxSearchWords(searchWord);
	        this.dehighlight();
	        if (!searchWord)
	            return;
	        this._findRecursive(this.el);
	    };
	    /**
	     * ハイライト表示をやめる
	     */
	    TextHighlighter.prototype.dehighlight = function () {
	        nativeForEach.call(this.el.querySelectorAll('mark'), function (node) {
	            node.parentNode.replaceChild(node.firstChild, node);
	        });
	        this.el.normalize();
	    };
	    /**
	     * 検索用の正規表現オブジェクトを返却する
	     * @param  searchWord 検索テキスト
	     * @param  flag       正規表現のフラグ
	     * @return パースした正規表現オブジェクト
	     */
	    TextHighlighter.prototype._getRxSearchWords = function (searchWord, flag) {
	        if (searchWord === void 0) { searchWord = ''; }
	        if (flag === void 0) { flag = 'gi'; }
	        return new RegExp(TextHighlighter._replaceWhitespaceWithPipe(TextHighlighter._getFullWidthAndHalfWidth(searchWord)), flag);
	    };
	    /**
	     * 要素内から検索ワードを再帰的に検索する
	     * @param node 検索する要素
	     */
	    TextHighlighter.prototype._findRecursive = function (node) {
	        if (node.nodeType === Node.TEXT_NODE) {
	            var text = node.data;
	            var matchedIndex = text.search(this.rxSearchWords);
	            var words = text.slice(matchedIndex).match(this.rxSearchWords);
	            var word = util_1.first(words);
	            var wordLength = (word || '').length;
	            if (matchedIndex > -1) {
	                var rest = document.createTextNode(text.substr(matchedIndex + wordLength));
	                var markNode = TextHighlighter._createMarker({ className: 'highlight' });
	                node.data = text.substr(0, matchedIndex);
	                markNode.appendChild(document.createTextNode(text.substr(matchedIndex, wordLength)));
	                node.parentNode.insertBefore(rest, node.nextSibling);
	                node.parentNode.insertBefore(markNode, node.nextSibling);
	                this._findRecursive(rest);
	            }
	        }
	        else if (node.nodeType === Node.ELEMENT_NODE) {
	            nativeForEach.call(node.childNodes, this._findRecursive.bind(this));
	        }
	    };
	    return TextHighlighter;
	})();


/***/ },
/* 1 */
/***/ function(module, exports) {

	/**
	 * 全角文字を半角文字に変換する
	 * @param  str 入力文字列
	 * @return 半角に変換後の文字列
	 */
	function toHalfWidth(str) {
	    if (str === void 0) { str = ''; }
	    return str.replace(/[！-～]/g, function (match) { return String.fromCharCode(match.charCodeAt(0) - 0xFEE0); });
	}
	exports.toHalfWidth = toHalfWidth;
	/**
	 * 半角文字を全角文字に変換する
	 * @param  str 入力文字列
	 * @return 全角に変換後の文字列
	 */
	function toFullWidth(str) {
	    if (str === void 0) { str = ''; }
	    return str.replace(/[!-~]/g, function (match) { return String.fromCharCode(match.charCodeAt(0) + 0xFEE0); });
	}
	exports.toFullWidth = toFullWidth;
	/**
	 * 正規表現で特殊な意味を持つ記号をエスケープする
	 * @param  str 入力文字列
	 * @return エスケープ後の文字列
	 */
	function escapeRegExp(str) {
	    if (str === void 0) { str = ''; }
	    return str.replace(/([.*+?^=!:${}()|[\]\/\\])/g, '\\$1');
	}
	exports.escapeRegExp = escapeRegExp;
	/**
	 * 配列の最初の要素を返却する
	 * @param  array 対象の配列
	 * @return 最初の要素
	 */
	function first(array) {
	    return array == null ? void 0 : array[0];
	}
	exports.first = first;


/***/ }
/******/ ])
});
;
